<template>
  <basic-container>
    <avue-crud
      ref="useCrud"
      :data="data"
      :option="option"
      :page.sync="page"
      :table-loading="loading"
      @selection-change="selectChange"
      @row-click="rowClickHandler"
      @refresh-change="handleRefresh"
      @size-change="sizeChange"
      @current-change="currentChange"
    >
      <template slot="menuLeft">
        <el-button icon="el-icon-plus" plain size="small" type="primary" @click="addClickHandler">创建
        </el-button>
        <el-button icon="el-icon-delete" plain size="small" type="danger" @click="delClickHandler">删除
        </el-button>
      </template>

      <template slot="menu" slot-scope="{row,index}">
        <el-button icon="el-icon-edit" plain size="small" type="text" @click="editClickHandler(row)">修改
        </el-button>
        <el-button icon="el-icon-delete" plain size="small" type="text" @click="delRowClickHandler(row)">删除
        </el-button>
      </template>
    </avue-crud>

    <!-- 新增 修改 -->
    <el-dialog
      v-dialogDrag
      :title="dialogTitle === 'add' ? '创建' : '修改'"
      :visible.sync="visible"
      append-to-body="true"
      class="avue-dialog"
      width="500px"
      @close="visibleCloseHandler"
    >
      <el-form ref="form" :model="form" :rules="rules" label-width="80px" size="small">
        <el-row>
          <el-col :span="24">
            <el-form-item label="名称：" prop="id">
              <el-input v-model="form.id"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="标签：" prop="name">
              <el-input v-model="form.name"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="图标：" prop="icon">
              <avue-input-icon v-model="form.icon" :icon-list="iconList" placeholder="请选择图标">
              </avue-input-icon>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="描述：" prop="description">
              <el-input v-model="form.description" :rows="2" type="textarea"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
         <el-button type="primary" @click="addSaveHandler">确 定</el-button>
         <el-button @click="visibleCloseHandler">取 消</el-button>
        </span>
    </el-dialog>
  </basic-container>
</template>

<script>
import iconList from "@/config/iconList";
import basicOption from "@/util/basic-option";
import {addSave, deleteStatus, editSave,  gridStatus} from "@/api/modeling/statusPool/api";
import func from "@/util/func";

export default {
  name: "homeConfig",
  data() {
    return {
      iconList: iconList,
      loading: false,
      data: [],
      option: {
        ...basicOption,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        calcHeight: -60,
        column: [
          {
            label: '名称',
            prop: 'id',
            sortable: true,
          },
          {
            label: '图标',
            prop: 'icon'
          },
          {
            label: '标签',
            prop: 'name',
            sortable: true,
          },
          {
            label: '描述',
            prop: 'description',
          },
        ]
      },
      dialogTitle: '',
      form: {
        id: "",
        name: "",
        description: ""
      },
      rules: {
        id: [
          {required: true, message: '请输入名称', trigger: 'blur'},
        ]
      },
      visible: false,
      selectList: [],
      lastIndex: null,
      page: {
        currentPage: 1,
        pageSize: 15,
        total: 0,
        pageSizes: [15, 30, 50, 100],
      },
    }
  },
  created() {
    this.getList();
  },
  methods: {
    getList() {
      gridStatus(this.page.currentPage, this.page.pageSize).then(res => {
        const data = res.data.data;
        this.data = data;
        this.page.total = res.data.total;
        this.loading = false;
      }).catch(err => {
        this.$message.error(err);
      });
    },

    // 表格刷新
    handleRefresh() {
      this.getList();
    },

    // 表格多选
    selectChange(row) {
      this.selectList = row;
    },

    //  条数
    sizeChange(val) {
      this.page.pageSize = val;
      this.getList();
    },

    // 页码
    currentChange(val) {
      this.page.currentPage = val;
      this.getList();
    },

    // 行单选
    rowClickHandler(row) {
      func.rowClickHandler(
        row,
        this.$refs.useCrud,
        this.lastIndex,
        (newIndex) => {
          this.lastIndex = newIndex;
        },
        () => {
          this.selectList = [];
        }
      );
    },

    // 创建按钮
    addClickHandler() {
      this.visible = true;
      this.dialogTitle = 'add';
    },

    // 编辑按钮
    editClickHandler(row) {
      this.visible = true;
      this.dialogTitle = 'edit';
      this.form = {...row};
    },

    // 删除
    delClickHandler() {
      if (this.selectList.length <= 0) {
        this.$message.error('请至少选择一条数据！');
        return;
      }
      this.$confirm('您确定要删除所选择的数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true;
        deleteStatus(this.selectList).then(res => {
          if (res.data.code === 200) {
            this.$message.success(res.data.obj);
            this.getList();
          }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },

    // 行单个删除
    delRowClickHandler(row) {
      this.$confirm('您确定要删除所选择的数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        const list = [row];
        this.loading = true;
        deleteStatus(list).then(res => {
          if (res.data.code === 200) {
            this.$message.success(res.data.obj);
            this.getList();
          }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },

    // 关闭对话框
    visibleCloseHandler() {
      const form = {
        id: "",
        name: "",
        imagePath: "",
        description: ""
      }
      this.form = form;
      this.visible = false;
      this.$refs.form.clearValidate();
    },

    // 创建或编辑保存
    addSaveHandler() {
      const saveFunction = this.dialogTitle === 'add' ? addSave : editSave;
      this.$refs.form.validate((valid) => {
        if (valid) {
          saveFunction(this.form).then(res => {
            if (res.data.code === 200) {
              this.$message.success(res.data.obj);
              this.loading = true;
              this.getList();
              this.visible = false;
            } else {
              this.$message.error(res.data.obj);
            }
          })
        } else {
          return false;
        }
      });
    },
  }
}
</script>

<style  lang="scss" scoped>
::v-deep {
  .el-scrollbar__wrap {
    overflow: auto !important;
  }

}
</style>
